==> kadu_0.6.0.2.orig.tar.gz: kadu/modules/notify/translations/notify_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Connection error</source>
        <translation>Verbindungsfehler</translation>
    </message>
    <message>
        <source>User changed status to online</source>
        <translation>Kontakt änderte Zustand auf Erreichbar</translation>
    </message>
    <message>
        <source>User changed status to busy</source>
        <translation>Kontakt änderte Zustand auf Beschäftigt</translation>
    </message>
    <message>
        <source>User changed status to invisible</source>
        <translation>Kontakt änderte Zustand auf Versteckt</translation>
    </message>
    <message>
        <source>User changed status to offline</source>
        <translation>Kontakt änderte Zustand auf Offline</translation>
    </message>
    <message>
        <source>New chat</source>
        <translation>Neuer Chat</translation>
    </message>
    <message>
        <source>New message</source>
        <translation>Neue Nachricht</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Benachrichtigungen</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>Event</source>
        <translation>Ereignis</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>New messages</source>
        <translation>Neue Nachricht</translation>
    </message>
    <message>
        <source>Notify about new messages only when window is inactive</source>
        <translation>Benachrichtige mich über neue Nachrichten nur, wenn das Fenster inaktiv ist</translation>
    </message>
    <message>
        <source>Status change</source>
        <translation>Zustandsänderung</translation>
    </message>
    <message>
        <source>Ignore status changes from available / busy to busy / available</source>
        <translation>Ignoriere Zustandsänderungen zwischen Erreichbar und Beschäftigt</translation>
    </message>
    <message>
        <source>Ignore changes right after connection to the server</source>
        <translation>Ignoriere Änderungen gleich nach der Verbindung zum Server</translation>
    </message>
    <message>
        <source>This option will supersede tooltips with users&apos; status
 changes upon establishing connection to the server</source>
        <translation>Diese Einstellung macht Benachrichtigungen überflüssig, 
kurz nachdem Sie sich mit dem Server verbunden haben</translation>
    </message>
    <message>
        <source>Notify about all users</source>
        <translation>Benachrichtige über alle Kontakte</translation>
    </message>
</context>
<context>
    <name>ConnectionErrorNotification</name>
    <message>
        <source>Connection error</source>
        <translation>Verbindungsfehler</translation>
    </message>
    <message>
        <source>&lt;b&gt;Error:&lt;/b&gt; (%1) %2</source>
        <translation>&lt;b&gt;Fehler:&lt;/b&gt; (%1) %2</translation>
    </message>
</context>
<context>
    <name>MessageNotification</name>
    <message>
        <source>Chat with &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Chat mit &lt;b&gt;%1&lt;/b&gt; </translation>
    </message>
    <message>
        <source>New message from &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Neue Nachricht von &lt;b&gt;%1&lt;/b&gt; </translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <source>Unable to find notifier for %1 event</source>
        <translation>Kann den Notifier für den Event %1 nicht finden</translation>
    </message>
    <message>
        <source>Move to &apos;Notify list&apos;</source>
        <translation>Verschieben in die &apos;Benachrichtigungsliste&apos;</translation>
    </message>
    <message>
        <source>User list</source>
        <translation>Kontaktliste</translation>
    </message>
    <message>
        <source>Move to &apos;User list&apos;</source>
        <translation>Verschieben in &apos;Kontaktliste&apos;</translation>
    </message>
    <message>
        <source>Notify list</source>
        <translation>Benachrichtigungsliste</translation>
    </message>
</context>
<context>
    <name>StatusChangedNotification</name>
    <message>
        <source>Status changed</source>
        <translation>Status geändert</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; changed status to &lt;i&gt;%2&lt;/i&gt;&lt;br/&gt; &lt;small&gt;%3&lt;/small&gt;</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; änderte Zustand in &lt;i&gt;%2&lt;/i&gt;&lt;br/&gt; &lt;small&gt;%3&lt;/small&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; changed status to &lt;i&gt;%2&lt;/i&gt;</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; änderte Zustand in &lt;i&gt;%2&lt;/i&gt;</translation>
    </message>
</context>
</TS>

==> kadu_0.6.5.3.orig.tar.gz: kadu/modules/notify/translations/notify_de.ts <==
<!DOCTYPE TS><TS>
<context>
    <name>@default</name>
    <message>
        <source>Connection error</source>
        <translation>Verbindungsfehler</translation>
    </message>
    <message>
        <source>User changed status to online</source>
        <translation>Kontakt änderte Zustand auf Erreichbar</translation>
    </message>
    <message>
        <source>User changed status to busy</source>
        <translation>Kontakt änderte Zustand auf Beschäftigt</translation>
    </message>
    <message>
        <source>User changed status to invisible</source>
        <translation>Kontakt änderte Zustand auf Versteckt</translation>
    </message>
    <message>
        <source>User changed status to offline</source>
        <translation>Kontakt änderte Zustand auf Offline</translation>
    </message>
    <message>
        <source>New chat</source>
        <translation>Neuer Chat</translation>
    </message>
    <message>
        <source>New message</source>
        <translation>Neue Nachricht</translation>
    </message>
    <message>
        <source>Notifications</source>
        <translation>Benachrichtigungen</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <source>Event</source>
        <translation>Ereignis</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>New messages</source>
        <translation>Neue Nachricht</translation>
    </message>
    <message>
        <source>Notify about new messages only when window is inactive</source>
        <translation>Benachrichtige mich über neue Nachrichten nur, wenn das Fenster inaktiv ist</translation>
    </message>
    <message>
        <source>Status change</source>
        <translation>Zustandsänderung</translation>
    </message>
    <message>
        <source>Ignore status changes from available / busy to busy / available</source>
        <translation>Ignoriere Zustandsänderungen zwischen Erreichbar und Beschäftigt</translation>
    </message>
    <message>
        <source>Ignore changes right after connection to the server</source>
        <translation>Ignoriere Änderungen gleich nach der Verbindung zum Server</translation>
    </message>
    <message>
        <source>This option will supersede tooltips with users&apos; status
 changes upon establishing connection to the server</source>
        <translation>Diese Einstellung macht Benachrichtigungen überflüssig, 
kurz nachdem Sie sich mit dem Server verbunden haben</translation>
    </message>
    <message>
        <source>Notify about all users</source>
        <translation>Benachrichtige über alle Kontakte</translation>
    </message>
    <message>
        <source>Silent Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable Silent Mode when Away</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ConnectionErrorNotification</name>
    <message>
        <source>Connection error</source>
        <translation>Verbindungsfehler</translation>
    </message>
    <message>
        <source>&lt;b&gt;Error:&lt;/b&gt; (%1) %2</source>
        <translation>&lt;b&gt;Fehler:&lt;/b&gt; (%1) %2</translation>
    </message>
</context>
<context>
    <name>MessageNotification</name>
    <message>
        <source>Chat with &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Chat mit &lt;b&gt;%1&lt;/b&gt; </translation>
    </message>
    <message>
        <source>New message from &lt;b&gt;%1&lt;/b&gt;</source>
        <translation>Neue Nachricht von &lt;b&gt;%1&lt;/b&gt; </translation>
    </message>
</context>
<context>
    <name>Notify</name>
    <message>
        <source>Unable to find notifier for %1 event</source>
        <translation>Kann den Notifier für den Event %1 nicht finden</translation>
    </message>
    <message>
        <source>Move to &apos;Notify list&apos;</source>
        <translation>Verschieben in die &apos;Benachrichtigungsliste&apos;</translation>
    </message>
    <message>
        <source>User list</source>
        <translation>Kontaktliste</translation>
    </message>
    <message>
        <source>Move to &apos;User list&apos;</source>
        <translation>Verschieben in &apos;Kontaktliste&apos;</translation>
    </message>
    <message>
        <source>Notify list</source>
        <translation>Benachrichtigungsliste</translation>
    </message>
    <message>
        <source>Enable Silent Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable Silent Mode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StatusChangedNotification</name>
    <message>
        <source>Status changed</source>
        <translation>Status geändert</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; changed status to &lt;i&gt;%2&lt;/i&gt;&lt;br/&gt; &lt;small&gt;%3&lt;/small&gt;</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; änderte Zustand in &lt;i&gt;%2&lt;/i&gt;&lt;br/&gt; &lt;small&gt;%3&lt;/small&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; changed status to &lt;i&gt;%2&lt;/i&gt;</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; änderte Zustand in &lt;i&gt;%2&lt;/i&gt;</translation>
    </message>
</context>
</TS>
